@@ -1,6 +1,14 @@
+from __future__ import annotations
+
+from typing import Any, TypeVar
+
+import deepmerge.merger
 from .core import StrategyList
 
 
+T = TypeVar("T")
+
+
 class FallbackStrategies(StrategyList):
     """
     The StrategyList containing fallback strategies.
@@ -9,11 +17,11 @@ class FallbackStrategies(StrategyList):
     NAME = "fallback"
 
     @staticmethod
-    def strategy_override(config, path, base, nxt):
+    def strategy_override(config: deepmerge.merger.Merger, path: list, base: Any, nxt: T) -> T:
         """use nxt, and ignore base."""
         return nxt
 
     @staticmethod
-    def strategy_use_existing(config, path, base, nxt):
+    def strategy_use_existing(config: deepmerge.merger.Merger, path: list, base: T, nxt: Any) -> T:
         """use base, and ignore next."""
         return base
